;;; oni-bats.el --- Configuration for bats-mode      -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.1201.134023
;; Package-Requires: (bats-mode oni-sh oni-yasnippet)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; Configuration for ‘bats-mode’.

;; This configuration pulls in ‘oni-sh’ because ‘bats-mode’ is derived from
;; ‘sh-mode’. Add the following to your init file in case you want to use this
;; configuration:
;;
;;     (with-eval-after-load 'bats-mode (require 'oni-bats))

;;; Code:

(require 'autoinsert)
(require 'oni-sh)
(require 'yasnippet)

(defconst oni-bats-root
  (file-name-directory
   (or load-file-name
       (buffer-file-name)))
  "The directory where ‘oni-bats’ was loaded from.")

(defconst oni-bats-snippets-dir
  (expand-file-name "snippets" oni-bats-root)
  "The directory where ‘oni-bats’ stores its snippets.")

(defun oni-bats-disable-shfmt-on-save-mode ()
  "Disable ‘shfmt-on-save-mode’."
  (shfmt-on-save-mode -1))

(defun oni-bats-snippets-initialize ()
  "Initialize the snippets for ‘oni-bats’."
  (when (boundp 'yas-snippet-dirs)
    (add-to-list 'yas-snippet-dirs oni-bats-snippets-dir t))
  (yas-load-directory oni-bats-snippets-dir))

(add-hook 'bats-mode-hook #'oni-bats-disable-shfmt-on-save-mode)

;;;###autoload
(with-eval-after-load 'autoinsert
  (add-to-list 'auto-insert-alist '(bats-mode nil "#!/usr/bin/env bats\n\n")))

(with-eval-after-load 'bats-mode
  (with-eval-after-load 'yasnippet
    (oni-bats-snippets-initialize)))

(provide 'oni-bats)
;;; oni-bats.el ends here
