;;; oni-c.el --- C configuration                     -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.0727.221058
;; Package-Requires: (oni-flycheck oni-lsp reformatter ccls rainbow-delimiters)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; C Configuration. Add the following to your init file in case you want to use
;; this configuration:
;;
;;     (with-eval-after-load 'cc-mode (require 'oni-c))

;;; Code:

(require 'cc-mode)
(require 'reformatter)

(defun oni-c--auto-fill-mode ()
  "Enable ‘auto-fill-mode’ only for comments."
  (setq-local comment-auto-fill-only-comments t)
  (auto-fill-mode))

(defun oni-c-ccls-lsp ()
  "Enable ‘lsp’ ensuring ‘ccls’ is used."
  (require 'ccls)
  (lsp))

(reformatter-define oni-c-clang-formatter
  :program "clang-format"
  :lighter ""
  :group 'oni-c)

(add-hook 'c-mode-hook #'oni-c--auto-fill-mode)
(add-hook 'c-mode-hook #'oni-c-ccls-lsp)
(add-hook 'c-mode-hook #'oni-c-clang-formatter-on-save-mode)
(add-hook 'c-mode-hook 'abbrev-mode)
(add-hook 'c-mode-hook 'display-fill-column-indicator-mode)
(add-hook 'c-mode-hook 'electric-indent-local-mode)
(add-hook 'c-mode-hook 'electric-pair-local-mode)
(add-hook 'c-mode-hook 'flycheck-mode)
(add-hook 'c-mode-hook 'rainbow-delimiters-mode)

(define-abbrev c-mode-abbrev-table "and" "&&" nil :system t)
(define-abbrev c-mode-abbrev-table "or" "||" nil :system t)

(provide 'oni-c)
;;; oni-c.el ends here
