;;; oni-common-lisp.el --- Common Lisp configuration     -*- lexical-binding: t; -*-

;; Copyright (C) 2017  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.1123.002421
;; Package-Requires: (oni-company oni-flycheck oni-paredit rainbow-delimiters slime slime-company)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:

;; Configuration for Common Lisp programming. Enables the following minor modes:

;;   - `company-mode': For auto-completion.
;;   - `flycheck-mode': For syntax checking.
;;   - `paredit-mode': For structured editing.
;;   - `rainbow-delimiters-mode': For delimiter highlighting.

;;; Code:

(require 'slime)

(defun oni-common-lisp--auto-fill-mode ()
  "Enable ‘auto-fill-mode’ only for comments."
  (setq-local comment-auto-fill-only-comments t)
  (auto-fill-mode))

(setq slime-lisp-implementations
      '((sbcl ("sbcl" "--noinform" "--no-linedit") :coding-system utf-8-unix)
        (clisp ("clisp") :coding-system utf-8-unix)))

(setq slime-default-lisp 'sbcl)

(slime-setup '(slime-fancy slime-company))

(add-hook 'lisp-mode-hook 'paredit-mode)
(add-hook 'lisp-mode-hook 'rainbow-delimiters-mode)
(add-hook 'lisp-mode-hook 'flycheck-mode)
(add-hook 'lisp-mode-hook 'company-mode)
(add-hook 'lisp-mode-hook 'oni-common-lisp--auto-fill-mode)

(provide 'oni-common-lisp)
;;; oni-common-lisp.el ends here
