;;; oni-company.el --- Company configuration         -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2022.1211.200707
;; Package-Requires: (company oni-prescient company-posframe diminish company-prescient)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; Configuration for `company-mode'.

;;; Code:

(require 'company)
(require 'company-dabbrev)
(require 'company-posframe)
(require 'company-prescient)
(require 'company-dabbrev)
(require 'diminish)

(defun oni-company--enable-posframe (_)
  "Enable posframe and remove this function from the hook."
  (when (display-graphic-p)
    (company-posframe-mode)
    (remove-hook 'company-completion-started-hook
                 'oni-company--enable-posframe)))

(setq company-dabbrev-downcase nil)
(setq company-dabbrev-ignore-case nil)
(setq company-idle-delay 0)
(setq company-minimum-prefix-length 1)
(setq company-tooltip-align-annotations t)

(setq company-frontends
      '(company-pseudo-tooltip-unless-just-one-frontend
        company-echo-metadata-frontend
        company-preview-frontend))

(when (member 'company-capf company-backends)
  (setf (car (member 'company-capf company-backends))
        '(company-capf :with company-yasnippet)))

(define-key company-mode-map (kbd "TAB") #'company-indent-or-complete-common)

(add-hook 'company-completion-started-hook 'oni-company--enable-posframe)

(company-prescient-mode)

(with-eval-after-load 'company (diminish 'company-mode))
(with-eval-after-load 'company-posframe (diminish 'company-posframe-mode))

(provide 'oni-company)
;;; oni-company.el ends here
