;;; oni-flycheck.el --- Flycheck configuration       -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.0715.221757
;; Package-Requires: (flycheck flycheck-posframe flycheck-cask)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; Configuration for flycheck. Add the following to your init file in case you
;; want to use this configuration:
;;
;;     (with-eval-after-load 'flycheck (require 'oni-flycheck))

;;; Code:

(require 'flycheck)
(require 'flycheck-posframe)

(mapc (lambda (c) (delq c flycheck-checkers))
      '(python-pylint python-pyflakes))

(setq flycheck-highlighting-mode 'columns)

(when (not (eql system-type 'windows-nt))
  (setq flycheck-mode-line-prefix "✓"))

(setq flycheck-emacs-args
      (append '("--eval" "(package-initialize)")
              flycheck-emacs-args))

(flycheck-posframe-configure-pretty-defaults)

(add-hook 'flycheck-mode-hook 'flycheck-cask-setup)
(add-hook 'flycheck-mode-hook 'flycheck-posframe-mode)

(provide 'oni-flycheck)
;;; oni-flycheck.el ends here
