;;; oni-git-commit.el --- Git commit configuration   -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2022.1207.083737
;; Package-Requires: (git-commit)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; Git commit configuration.

;;; Code:

(require 'git-commit)

(eval-when-compile
  (require 'refill))

(defun oni-git-commit-disable-comment-refill (_ _ _)
  "Clear ‘refill-doit’ if ‘auto-fill-inhibit-regexp’ matches."
  (when (and git-commit-mode
             refill-doit
             (save-excursion
               (goto-char refill-doit)
               (looking-at auto-fill-inhibit-regexp)))
    (setq refill-doit nil)))

(defun oni-git-commit-set-auto-fill-inhibit-regexp ()
  "Set the ‘auto-fill-inhibit-regexp’ to match git commit comments."
  (setq-local auto-fill-inhibit-regexp (rx (minimal-match (zero-or-more "\n")) "#")))

(add-hook 'git-commit-mode-hook #'oni-git-commit-set-auto-fill-inhibit-regexp)
(add-hook 'git-commit-mode-hook 'electric-pair-local-mode)
(add-hook 'git-commit-mode-hook 'electric-quote-local-mode)
(add-hook 'git-commit-mode-hook 'refill-mode)

(add-function :after (symbol-function 'refill-after-change-function)
              #'oni-git-commit-disable-comment-refill)

(provide 'oni-git-commit)
;;; oni-git-commit.el ends here
