;;; oni-grep.el --- Grep configuration               -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2023.0615.232817

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; Grep configuration

;;; Code:

(require 'find-dired)
(require 'grep)

(add-to-list 'grep-files-aliases '("msbuild" . "*.targets *.proj"))

(when (eq system-type 'windows-nt)
  (setq find-program (shell-quote-argument "c:/cygwin64/bin/find.exe"))
  (setq grep-program (shell-quote-argument "c:/cygwin64/bin/grep.exe"))
  (setq grep-use-null-device nil)

  (let ((exe (shell-quote-argument "c:/cygwin64/bin/ls.exe")))
    (setq find-ls-option
          (cons (concat "-exec " exe " -ld {} \";\"") "-ld"))))

(add-to-list 'display-buffer-alist
             '("\\`\\*grep\\*\\'" display-buffer-in-side-window
               (side . bottom)
               (slot . 0)
               (window-height . 0.33)))

(add-to-list 'grep-find-ignored-directories ".cask")

(add-hook 'grep-mode-hook 'hl-line-mode)

(provide 'oni-grep)
;;; oni-grep.el ends here
