;;; oni-haml.el --- HAML configuration               -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.1201.134032
;; Package-Requires: (oni-yasnippet)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; My configuration for ‘haml-mode’.

;;; Code:

(require 'yasnippet)

(defconst oni-haml-root
  (file-name-directory
   (or load-file-name
       (buffer-file-name)))
  "The directory where ‘oni-haml’ was loaded from.")

(defconst oni-haml-snippets-dir
  (expand-file-name "snippets" oni-haml-root)
  "The directory where ‘oni-haml’ stores its snippets.")

(defun oni-haml-snippets-initialize ()
  "Initialize the snippets for ‘oni-haml’."
  (when (boundp 'yas-snippet-dirs)
    (add-to-list 'yas-snippet-dirs oni-haml-snippets-dir t))
  (yas-load-directory oni-haml-snippets-dir))

(defun oni-haml--auto-fill-mode ()
  "Enable ‘auto-fill-mode’ only for comments."
  (setq-local comment-auto-fill-only-comments t)
  (auto-fill-mode))

(add-hook 'haml-mode-hook 'oni-haml--auto-fill-mode)

(with-eval-after-load 'haml-mode
  (with-eval-after-load 'yasnippet
    (oni-haml-snippets-initialize)))

(provide 'oni-haml)
;;; oni-haml.el ends here
