;;; oni-html.el --- HTML configuration               -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.1201.134113
;; Package-Requires: (oni-yasnippet)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; HTML configuration

;;; Code:

(require 'yasnippet)

(defconst oni-html-root
  (file-name-directory
   (or load-file-name
       (buffer-file-name)))
  "The directory where ‘oni-html’ was loaded from.")

(defconst oni-html-snippets-dir
  (expand-file-name "snippets" oni-html-root)
  "The directory where ‘oni-html’ stores its snippets.")

(defun oni-html-snippets-initialize ()
  "Initialize the snippets for ‘oni-html’."
  (when (boundp 'yas-snippet-dirs)
    (add-to-list 'yas-snippet-dirs oni-html-snippets-dir t))
  (yas-load-directory oni-html-snippets-dir))

(defun oni-html--auto-fill-mode ()
  "Enable ‘auto-fill-mode’ only for comments."
  (setq-local comment-auto-fill-only-comments t)
  (auto-fill-mode))

(add-hook 'html-mode-hook 'electric-pair-local-mode)
(add-hook 'html-mode-hook 'oni-html--auto-fill-mode)

(with-eval-after-load 'sgml-mode
  (with-eval-after-load 'yasnippet
    (oni-html-snippets-initialize)))

(provide 'oni-html)
;;; oni-html.el ends here
