;;; oni-nxml.el --- NXML configuration               -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.1201.134152
;; Package-Requires: (oni-yasnippet reformatter)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; NXML configuration

;;; Code:

(require 'yasnippet)

(defconst oni-nxml-root
  (file-name-directory
   (or load-file-name
       (buffer-file-name)))
  "The directory where ‘oni-nxml’ was loaded from.")

(defconst oni-nxml-snippets-dir
  (expand-file-name "snippets" oni-nxml-root)
  "The directory where ‘oni-nxml’ stores its snippets.")

(defun oni-nxml-snippets-initialize ()
  "Initialize the snippets for ‘oni-nxml’."
  (when (boundp 'yas-snippet-dirs)
    (add-to-list 'yas-snippet-dirs oni-nxml-snippets-dir t))
  (yas-load-directory oni-nxml-snippets-dir))

(defun oni-nxml--auto-fill-mode ()
  "Enable ‘auto-fill-mode’ only for comments."
  (setq-local comment-auto-fill-only-comments t)
  (auto-fill-mode))

(add-hook 'nxml-mode-hook 'oni-nxml--auto-fill-mode)

(reformatter-define oni-nxml-xmllint
  :program "xmllint"
  :args '("--nonet" "--format" "-")
  :lighter "")

;;;###autoload
(add-to-list 'auto-mode-alist '("\\.targets\\'" . nxml-mode))
;;;###autoload
(add-to-list 'auto-mode-alist '("\\.proj\\'" . nxml-mode))

(with-eval-after-load 'nxml-mode
  (with-eval-after-load 'yasnippet
    (oni-nxml-snippets-initialize)))

(provide 'oni-nxml)
;;; oni-nxml.el ends here
