;;; oni-ruby.el --- Ruby configuration               -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.1201.134041
;; Package-Requires: (ruby-mode oni-yasnippet)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; Ruby configuration.

;;; Code:

(require 'yasnippet)

(defconst oni-ruby-root
  (file-name-directory
   (or load-file-name
       (buffer-file-name)))
  "The directory where ‘oni-ruby’ was loaded from.")

(defconst oni-ruby-snippets-dir
  (expand-file-name "snippets" oni-ruby-root)
  "The directory where ‘oni-ruby’ stores its snippets.")

(defun oni-ruby-snippets-initialize ()
  "Initialize the snippets for ‘oni-ruby’."
  (when (boundp 'yas-snippet-dirs)
    (add-to-list 'yas-snippet-dirs oni-ruby-snippets-dir))
  (yas-load-directory oni-ruby-snippets-dir))

(defun oni-ruby--auto-fill-mode ()
  "Enable ‘auto-fill-mode’ only for comments."
  (setq-local comment-auto-fill-only-comments t)
  (auto-fill-mode))

(add-hook 'ruby-mode-hook 'display-fill-column-indicator-mode)
(add-hook 'ruby-mode-hook 'electric-indent-local-mode)
(add-hook 'ruby-mode-hook 'electric-pair-local-mode)
(add-hook 'ruby-mode-hook 'oni-ruby--auto-fill-mode)

(with-eval-after-load 'ruby-mode
  (with-eval-after-load 'yasnippet
    (oni-ruby-snippets-initialize)))

(provide 'oni-ruby)
;;; oni-ruby.el ends here
