;;; oni-scheme.el --- Scheme configuration           -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2023.0718.212002
;; Package-Requires: (oni-company oni-paredit rainbow-delimiters geiser geiser-guile)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; Scheme configuration.

;;; Code:

(require 'geiser)
(require 'geiser-impl)
(require 'geiser-repl)

(defun oni-scheme--auto-fill-mode ()
  "Enable ‘auto-fill-mode’ only for comments."
  (setq-local comment-auto-fill-only-comments t)
  (auto-fill-mode))

(defun oni-scheme-geiser-repl-remove-paredit-newline-keys ()
  "Disable ‘C-j’ and ‘RET’ keybindings from ‘geiser-repl-mode’."
  (let ((oldmap (map-elt minor-mode-map-alist 'paredit-mode))
        (newmap (make-sparse-keymap)))
    (set-keymap-parent newmap oldmap)
    (define-key newmap (kbd "RET") nil)
    (define-key newmap (kbd "C-j") nil)
    (make-local-variable 'minor-mode-overriding-map-alist)
    (push `(paredit-mode . ,newmap) minor-mode-overriding-map-alist)))

(add-hook 'scheme-mode-hook 'company-mode)
(add-hook 'scheme-mode-hook 'display-fill-column-indicator-mode)
(add-hook 'scheme-mode-hook 'oni-scheme--auto-fill-mode)
(add-hook 'scheme-mode-hook 'paredit-mode)
(add-hook 'scheme-mode-hook 'rainbow-delimiters-mode)

(add-hook 'geiser-repl-mode-hook 'paredit-mode)
;;; Make sure this gets added _after_ ‘paredit-mode’ so that it gets executed
;;; later.
(add-hook 'geiser-repl-mode-hook #'oni-scheme-geiser-repl-remove-paredit-newline-keys 90)

(setq geiser-default-implementation 'guile)

(setq geiser-repl-history-filename
      (expand-file-name "data/geiser-history" user-emacs-directory))

;;;###autoload
(add-to-list 'interpreter-mode-alist '("scsh" . scheme-mode))

(provide 'oni-scheme)
;;; oni-scheme.el ends here
