;;; oni-sh.el --- sh-mode configuration              -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.0715.215613
;; Package-Requires: (reformatter oni-flycheck oni-smartparens)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; Configuration and helpers for `sh-mode'.

;; This sets the following minor modes for ‘sh-mode’:
;; - ‘electric-indent-local-mode’
;; - ‘electric-pair-local-mode’
;; - ‘display-fill-column-indicator-mode’
;; - ‘flycheck-mode’

;; It also defines a formatter using ‘reformatter’ which runs the shfmt utility.
;; This is set up to run after saving a shell script.

;; Add the following to your init file if you want to use this configuration:
;;
;;     (with-eval-after-load 'sh-script (require 'oni-sh))

;;; Code:

(require 'reformatter)

(reformatter-define shfmt
  :program "shfmt"
  :args '("-s" "-i" "4" "-bn" "-ci" "-sr")
  :lighter ""
  :group 'shfmt)

(add-hook 'sh-mode-hook 'display-fill-column-indicator-mode)
(add-hook 'sh-mode-hook 'electric-indent-local-mode)
(add-hook 'sh-mode-hook 'flycheck-mode)
(add-hook 'sh-mode-hook 'shfmt-on-save-mode)
(add-hook 'sh-mode-hook 'smartparens-mode)

;;;###autoload
(add-to-list 'auto-mode-alist '("PKGBUILD\\'" . sh-mode))

(provide 'oni-sh)
;;; oni-sh.el ends here
