;;; oni-twig.el --- Twig configuration               -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.1201.134109
;; Package-Requires: (twig-mode oni-yasnippet)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; Configuration for ‘twig-mode’.

;;; Code:

(require 'yasnippet)

(defconst oni-twig-root
  (file-name-directory
   (or load-file-name
       (buffer-file-name)))
  "The directory where ‘oni-twig’ was loaded from.")

(defconst oni-twig-snippets-dir
  (expand-file-name "snippets" oni-twig-root)
  "The directory where ‘oni-twig’ stores its snippets.")

(defun oni-twig-snippets-initialize ()
  "Initialize the snippets for ‘oni-twig’."
  (when (boundp 'yas-snippet-dirs)
    (add-to-list 'yas-snippet-dirs oni-twig-snippets-dir))
  (yas-load-directory oni-twig-snippets-dir))

(defun oni-twig--auto-fill-mode ()
  "Enable ‘auto-fill-mode’ only for comments."
  (setq-local comment-auto-fill-only-comments t)
  (auto-fill-mode))

(add-hook 'twig-mode-hook 'oni-twig--auto-fill-mode)

(with-eval-after-load 'twig-mode
  (with-eval-after-load 'yasnippet
    (oni-twig-snippets-initialize)))

(provide 'oni-twig)
;;; oni-twig.el ends here
