;;; oni-web.el --- Web configuration                 -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.1123.002232
;; Package-Requires: (web-mode oni-flycheck)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; Configuration for `web-mode'.

;;; Code:

(require 'web-mode)
(require 'whitespace)

(defun oni-web--whitespace-mode ()
  "Enable whitespace mode with only tabs showing."
  (setq-local whitespace-style '(face tabs))
  (whitespace-mode))

(defun oni-web--auto-fill-mode ()
  "Enable ‘auto-fill-mode’ only for comments."
  (setq-local comment-auto-fill-only-comments t)
  (auto-fill-mode))

(setq web-mode-attr-indent-offset 2)
(setq web-mode-auto-quote-style 1)
(setq web-mode-code-indent-offset 2)
(setq web-mode-comment-style 2)
(setq web-mode-css-indent-offset 2)
(setq web-mode-css-indent-offset 2)

(add-hook 'web-mode-hook 'electric-pair-local-mode)
(add-hook 'web-mode-hook 'flycheck-mode)
(add-hook 'web-mode-hook #'oni-web--whitespace-mode)
(add-hook 'web-mode-hook 'oni-web--auto-fill-mode)

;;;###autoload
(add-to-list 'auto-mode-alist '("\\.blade\\.php\\'" . web-mode))

(provide 'oni-web)
;;; oni-web.el ends here
