;;; oni-yaml.el --- YAML configuration               -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2024.0205.164705
;; Package-Requires: (yaml-mode oni-flycheck oni-highlight-indent-guides indent-tools yaml-imenu yaml-pro)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; YAML configuration.

;;; Code:

(require 'indent-tools)
(require 'yaml-imenu)

;; Don't mind if treesit can't be loaded, maybe this Emacs doesn't have it.
(require 'treesit nil t)

(defun oni-yaml--auto-fill-mode ()
  "Enable ‘auto-fill-mode’ only for comments."
  (setq-local comment-auto-fill-only-comments t)
  (auto-fill-mode))

(defun oni-yaml--enable-hooks (hook)
  "Enable all hooks I use for editing yaml files for HOOK."
  (add-hook hook 'display-fill-column-indicator-mode)
  (add-hook hook 'electric-indent-local-mode)
  (add-hook hook 'electric-pair-local-mode)
  (add-hook hook 'highlight-indent-guides-mode)
  (add-hook hook 'oni-yaml--auto-fill-mode)
  (add-hook hook 'yaml-imenu-enable)
  (add-hook hook 'yaml-pro-mode))

(define-key yaml-mode-map (kbd "C-c >") 'indent-tools-hydra/body)

(oni-yaml--enable-hooks 'yaml-mode-hook)

(when (and (functionp 'treesit-available-p)
         (treesit-available-p)
         (treesit-ready-p 'yaml))
  (add-to-list 'major-mode-remap-alist '(yaml-mode . yaml-ts-mode))
  (oni-yaml--enable-hooks 'yaml-ts-mode-hook))

(provide 'oni-yaml)
;;; oni-yaml.el ends here
