#!/usr/bin/env bats

@test "Opening emacs loads oni-core" {
    run emacs -batch -l package -f package-initialize \
        -eval "(prin1 (featurep 'oni-core))"

    echo "$output"

    [[ "$output" == *"t" ]]
}

@test "C-a is bound to oni-core-move-to-beginning-of-dwim" {
    run emacs -batch -l package -f package-initialize \
        -eval "(prin1 (key-binding (kbd \"C-a\")))"

    echo "$output"

    [[ "$output" == *"oni-core-move-beginning-of-dwim" ]]
}

@test "C-e is bound to oni-core-move-to-end-of-dwim" {
    run emacs -batch -l package -f package-initialize \
        -eval "(prin1 (key-binding (kbd \"C-e\")))"

    echo "$output"

    [[ "$output" == *"oni-core-move-end-of-dwim" ]]
}

@test "Starting Emacs diminishes gcmh-mode" {
    run emacs -batch -l package -f package-initialize -l subr-x \
        -eval "(prin1 (string-empty-p (car (alist-get 'gcmh-mode minor-mode-alist))))"

    echo "$output"

    [[ "$output" == *"t" ]]
}

@test "Starting Emacs enables gcmh-mode" {
    run emacs -batch -l package -f package-initialize \
        -eval "(prin1 (bound-and-true-p gcmh-mode))"

    echo "$output"

    [[ "$output" == *"t" ]]
}

@test "Starting Emacs diminishes ws-butler-global-mode" {
    run emacs -batch -l package -f package-initialize -l subr-x \
        -eval "(prin1 (string-empty-p (car (alist-get 'ws-butler-mode minor-mode-alist))))"

    echo "$output"

    [[ "$output" == *"t" ]]
}

@test "Starting Emacs turns on ws-butler-mode" {
    run emacs -batch -l package -f package-initialize \
        -eval "(prin1 (bound-and-true-p ws-butler-mode))"

    echo "$output"

    [[ "$output" == *"t" ]]
}
